==> haskell-byteable-0.1.1-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byteable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 byteable
version:              0.1.1
visibility:           public
id:                   byteable-0.1.1-FeSdIMqUIcwI3U3IhpOBJ3
key:                  byteable-0.1.1-FeSdIMqUIcwI3U3IhpOBJ3
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-byteable
synopsis:             Type class for sequence of bytes
description:
    Abstract class to manipulate sequence of bytes

    The use case of this class is abstracting manipulation of
    types that are just wrapping a bytestring with stronger and
    more meaniful name.

    Usual definition of those types are of the form: newtype MyType = MyType ByteString

category:             Data
abi:                  5392bfb81d8babd880ba9df7d549a3ce
exposed:              True
exposed-modules:      Data.Byteable
import-dirs:          /usr/lib/ghc-8.10.2/site-local/byteable-0.1.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/byteable-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byteable
hs-libraries:         HSbyteable-0.1.1-FeSdIMqUIcwI3U3IhpOBJ3
depends:              base-4.14.1.0 bytestring-0.10.10.0
haddock-interfaces:   /usr/share/doc/haskell-byteable/html/byteable.haddock
haddock-html:         /usr/share/doc/haskell-byteable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-byteable-0.1.1-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byteable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 byteable
version:              0.1.1
visibility:           public
id:                   byteable-0.1.1-2tCrGdFfJISCmoPhB610i6
key:                  byteable-0.1.1-2tCrGdFfJISCmoPhB610i6
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-byteable
synopsis:             Type class for sequence of bytes
description:
    Abstract class to manipulate sequence of bytes

    The use case of this class is abstracting manipulation of
    types that are just wrapping a bytestring with stronger and
    more meaniful name.

    Usual definition of those types are of the form: newtype MyType = MyType ByteString

category:             Data
abi:                  0eb2d6c3c0e92029dba93d247545e781
exposed:              True
exposed-modules:      Data.Byteable
import-dirs:          /usr/lib/ghc-8.10.3/site-local/byteable-0.1.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/byteable-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byteable
hs-libraries:         HSbyteable-0.1.1-2tCrGdFfJISCmoPhB610i6
depends:              base-4.14.1.0 bytestring-0.10.12.0
haddock-interfaces:   /usr/share/doc/haskell-byteable/html/byteable.haddock
haddock-html:         /usr/share/doc/haskell-byteable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
